AcsGeoidQuery

Enum AcsGeoidQuery 

pub enum AcsGeoidQuery {
    State(Option<State>),
    County(Option<State>, Option<County>),
    CountySubdivision(State, Option<County>, Option<CountySubdivision>),
    Place(Option<State>, Option<Place>),
    CensusTract(State, Option<County>, Option<CensusTract>),
    BlockGroup(State, Option<County>, Option<CensusTract>, Option<BlockGroup>),
}
enumeration representing the scopes of various ACS queries.

when running an ACS query at a given GEOID hierarchical level, there are a set of required (aka, not Optional) components which can be coupled with Optional (wildcard) components to construct a query.

Variants

Implementations

Source

impl AcsGeoidQuery

pub fn new( geoid: Option<Geoid>, wildcard: Option<GeoidType>, ) -> Result<AcsGeoidQuery, String>

Examples

when no wildcard is provided, the query is constructed for an exact location, which should return a single result.

use bamcensus_core::model::identifier::{fips, Geoid, GeoidType};
use bamcensus_acs::model::AcsGeoidQuery;;

let geoid = Geoid::County(fips::State(8), fips::County(1));
let query = AcsGeoidQuery::new(Some(geoid), None).unwrap();
let key = query.to_query_key();
assert_eq!(key, String::from("&for=county:001&in=state:08"));

some combinations simply append a wildcard one level below the geoid, for example, tacking a county=* on top of state=08.

use bamcensus_core::model::identifier::{fips, Geoid, GeoidType};
use bamcensus_acs::model::AcsGeoidQuery;;

let geoid = Geoid::State(fips::State(8));
let wildcard = GeoidType::County;
let query = AcsGeoidQuery::new(Some(geoid), Some(wildcard)).unwrap();
let key = query.to_query_key();
assert_eq!(key, String::from("&for=county:*&in=state:08"));

some interpolate the wildcard into a geoid in ways that do not require being reported in the query, such as adding a wildcard to a tract query. in this case, the query simply drops the county wildcard, as it is implied.

use bamcensus_core::model::identifier::{fips, Geoid, GeoidType};
use bamcensus_acs::model::AcsGeoidQuery;;

let geoid = Geoid::CensusTract(fips::State(8), fips::County(1), fips::CensusTract(1));
let wildcard = GeoidType::County;
let query = AcsGeoidQuery::new(Some(geoid), Some(wildcard)).unwrap();
let key = query.to_query_key();
assert_eq!(key, String::from("&for=tract:000001&in=state:08"));
Returns

URL query string for calls to the US Census ACS API “for” section, which set the spatial scope and granularity of the query result.

pub fn to_query_key(&self) -> String

a query key for a unique data row in the census API. depending on the AcsGeoidQuery and the presence/absence of FIPS values, wildcards (“*”) will be inserted at any level.

pub fn response_geoid_type(&self) -> GeoidType

pub fn response_column_names(&self) -> Vec<String>

pub fn response_column_count(&self) -> usize

pub fn get_geoid_type(&self) -> GeoidType

pub fn build_deserialize_geoid_fn(&self) -> DeserializeGeoidFn

builds a function that unpacks the ACS query values representing a geoid. these return as values in an array of different lengths, depending on the scope of the original query.